@@ -4,7 +4,7 @@
  *              to build a moderately scalable and highly available server
  *              based on a cluster of servers, with more flexibility.
  *
- * Version:     $Id: tcp_vs.c,v 1.15.2.1 2004/10/30 16:28:14 wensong Exp $
+ * Version:     $Id: tcp_vs.c,v 1.15.2.2 2004/12/08 13:58:13 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -56,6 +56,7 @@ EXPORT_SYMBOL(tcp_vs_get_debug_level);
 #endif
 EXPORT_SYMBOL(sysctl_ktcpvs_unload);
 EXPORT_SYMBOL(sysctl_ktcpvs_keepalive_timeout);
+EXPORT_SYMBOL(sysctl_ktcpvs_read_timeout);
 EXPORT_SYMBOL(tcp_vs_srvconn_get);
 EXPORT_SYMBOL(tcp_vs_srvconn_put);
 EXPORT_SYMBOL(tcp_vs_srvconn_new);
@@ -276,6 +277,7 @@ tcp_vs_conn_handle(struct tcp_vs_conn *conn, struct tcp_vs_service *svc)
 	struct socket *csock, *dsock;
 	DECLARE_WAITQUEUE(wait1, current);
 	DECLARE_WAITQUEUE(wait2, current);
+	unsigned long lastupdated;
 
 	EnterFunction(5);
 
@@ -327,7 +329,9 @@ tcp_vs_conn_handle(struct tcp_vs_conn *conn, struct tcp_vs_service *svc)
 	 *        We need to explore.
 	 */
 
-	while (1) {
+	lastupdated = jiffies;
+
+	while ((jiffies - lastupdated) < sysctl_ktcpvs_read_timeout * HZ) {
 		/* if the connection is closed, go out of this loop */
 		if (dsock->sk->state != TCP_ESTABLISHED
 		    && dsock->sk->state != TCP_CLOSE_WAIT)
@@ -341,12 +345,14 @@ tcp_vs_conn_handle(struct tcp_vs_conn *conn, struct tcp_vs_service *svc)
 		if (!skb_queue_empty(&(dsock->sk->receive_queue))) {
 			if (tcp_vs_relay_socket(dsock, csock) == 0)
 				break;
+			lastupdated = jiffies;
 		}
 
 		/* Do we have data from client? */
 		if (!skb_queue_empty(&(csock->sk->receive_queue))) {
 			if (tcp_vs_relay_socket(csock, dsock) == 0)
 				break;
+			lastupdated = jiffies;
 		}
 
 		if (skb_queue_empty(&(dsock->sk->receive_queue))
@@ -364,7 +370,7 @@ tcp_vs_conn_handle(struct tcp_vs_conn *conn, struct tcp_vs_service *svc)
 			add_wait_queue(dsock->sk->sleep, &wait2);
 			__set_current_state(TASK_INTERRUPTIBLE);
 
-			schedule();
+			schedule_timeout(HZ);
 
 			__set_current_state(TASK_RUNNING);
 			remove_wait_queue(csock->sk->sleep, &wait1);
