@@ -5,7 +5,7 @@
  *
  * tcp_vs.h: main structure definitions and function prototypes
  *
- * $Id: tcp_vs.h,v 1.21.2.1 2004/10/30 16:28:14 wensong Exp $
+ * $Id: tcp_vs.h,v 1.21.2.2 2004/12/08 13:58:13 wensong Exp $
  *
  */
 
@@ -14,7 +14,7 @@
 
 #include <asm/types.h>		/* For __uXX types */
 
-#define TCP_VS_VERSION_CODE		0x00000E
+#define TCP_VS_VERSION_CODE		0x000011
 #define NVERSION(version)                       \
 	(version >> 16) & 0xFF,                 \
 	(version >> 8) & 0xFF,                  \
@@ -247,6 +247,7 @@ enum {
 	NET_KTCPVS_MAXBACKLOG = 3,
 	NET_KTCPVS_ZEROCOPY_SEND = 4,
 	NET_KTCPVS_KEEPALIVE_TIMEOUT = 5,
+	NET_KTCPVS_READ_TIMEOUT = 6,
 };
 
 
@@ -441,6 +442,7 @@ extern int sysctl_ktcpvs_unload;
 extern int sysctl_ktcpvs_max_backlog;
 extern int sysctl_ktcpvs_zerocopy_send;
 extern int sysctl_ktcpvs_keepalive_timeout;
+extern int sysctl_ktcpvs_read_timeout;
 
 extern int tcp_vs_flush(void);
 extern int tcp_vs_control_start(void);
