@@ -4,7 +4,7 @@
  *              to build a moderately scalable and highly available server
  *              based on a cluster of servers, with more flexibility.
  *
- * Version:     $Id: tcp_vs_ctl.c,v 1.13.2.1 2004/10/30 16:28:14 wensong Exp $
+ * Version:     $Id: tcp_vs_ctl.c,v 1.13.2.2 2004/12/08 13:58:13 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -63,6 +63,7 @@ int sysctl_ktcpvs_unload = 0;
 int sysctl_ktcpvs_max_backlog = 2048;
 int sysctl_ktcpvs_zerocopy_send = 0;
 int sysctl_ktcpvs_keepalive_timeout = 30;
+int sysctl_ktcpvs_read_timeout = 180;
 
 #ifdef CONFIG_TCP_VS_DEBUG
 static int sysctl_ktcpvs_debug_level = 0;
@@ -1061,6 +1062,9 @@ static ctl_table ktcpvs_table[] = {
 	{NET_KTCPVS_KEEPALIVE_TIMEOUT, "keepalive_timeout",
 	 &sysctl_ktcpvs_keepalive_timeout,
 	 sizeof(int), 0644, NULL, &proc_dointvec},
+	{NET_KTCPVS_READ_TIMEOUT, "read_timeout",
+	 &sysctl_ktcpvs_read_timeout,
+	 sizeof(int), 0644, NULL, &proc_dointvec},
 	{0}
 };
 
