@@ -6,7 +6,7 @@
  *
  * tcp_vs_srvconn.c: server connection management for KTCPVS
  *
- * Version:     $Id: tcp_vs_srvconn.c,v 1.2 2003/02/24 01:20:36 wensong Exp $
+ * Version:     $Id: tcp_vs_srvconn.c,v 1.5 2003/05/23 02:51:12 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -67,8 +67,8 @@ tcp_vs_srvconn_hashkey(__u32 addr, __u16 port)
 {
 	unsigned addrh = ntohl(addr);
 
-	return (addrh^(addrh>>SRVCONN_TAB_BITS)^ntohs(port))
-		& SRVCONN_TAB_MASK;
+	return (addrh ^ (addrh >> SRVCONN_TAB_BITS) ^ ntohs(port))
+	    & SRVCONN_TAB_MASK;
 }
 
 
@@ -76,13 +76,15 @@ tcp_vs_srvconn_hashkey(__u32 addr, __u16 port)
  *	Hashes a connection into the server connection table.
  *	returns bool success.
  */
-static inline int tcp_vs_srvconn_hash(server_conn_t *sc)
+static inline int
+tcp_vs_srvconn_hash(server_conn_t * sc)
 {
 	unsigned hash;
 
 	if (sc->flags & SRVCONN_F_HASHED) {
-		TCP_VS_ERR("tcp_vs_srvconn_hash: request for already hashed, "
-			  "called from %p\n", __builtin_return_address(0));
+		TCP_VS_ERR
+		    ("tcp_vs_srvconn_hash: request for already hashed, "
+		     "called from %p\n", __builtin_return_address(0));
 		return 0;
 	}
 
@@ -104,17 +106,20 @@ static inline int tcp_vs_srvconn_hash(server_conn_t *sc)
  *	UNhashes a connection from the server connection table.
  *	returns bool success.
  */
-static inline void __tcp_vs_srvconn_unhash(server_conn_t *sc)
+static inline void
+__tcp_vs_srvconn_unhash(server_conn_t * sc)
 {
 	list_del(&sc->list);
 	sc->flags &= ~SRVCONN_F_HASHED;
 }
 
-static inline int tcp_vs_srvconn_unhash(server_conn_t *sc)
+static inline int
+tcp_vs_srvconn_unhash(server_conn_t * sc)
 {
 	if (!(sc->flags & SRVCONN_F_HASHED)) {
-		TCP_VS_ERR("tcp_vs_srvconn_unhash: request for unhash flagged"
-			   ", called from %p\n", __builtin_return_address(0));
+		TCP_VS_ERR
+		    ("tcp_vs_srvconn_unhash: request for unhash flagged"
+		     ", called from %p\n", __builtin_return_address(0));
 		return 0;
 	}
 
@@ -132,7 +137,8 @@ static inline int tcp_vs_srvconn_unhash(server_conn_t *sc)
  *	Get a server connection associated with supplied parameters from
  *	the server connection table.
  */
-server_conn_t *tcp_vs_srvconn_get(__u32 addr, __u16 port)
+server_conn_t *
+tcp_vs_srvconn_get(__u32 addr, __u16 port)
 {
 	unsigned hash;
 	server_conn_t *sc;
@@ -144,12 +150,12 @@ server_conn_t *tcp_vs_srvconn_get(__u32 addr, __u16 port)
 	/* need disable the bottom half */
 	spin_lock(&srvconn_lock);
 
-	for (e=l->next; e!=l; e=e->next) {
+	for (e = l->next; e != l; e = e->next) {
 		sc = list_entry(e, server_conn_t, list);
-		if (addr==sc->addr && port==sc->port) {
+		if (addr == sc->addr && port == sc->port) {
 			/* HIT */
 			__tcp_vs_srvconn_unhash(sc);
-			del_slowtimer(&sc->keepalive_timer);
+			tcp_vs_del_slowtimer(&sc->keepalive_timer);
 			spin_unlock(&srvconn_lock);
 			return sc;
 		}
@@ -164,12 +170,13 @@ server_conn_t *tcp_vs_srvconn_get(__u32 addr, __u16 port)
 /*
  *      Restart its timer with its timeout and put back the conn.
  */
-void tcp_vs_srvconn_put(server_conn_t *sc)
+void
+tcp_vs_srvconn_put(server_conn_t * sc)
 {
 	/* reset it expire in its timeout */
 	sc->keepalive_timer.expires = jiffies
-		+ sysctl_ktcpvs_keepalive_timeout * HZ;
-	add_slowtimer(&sc->keepalive_timer);
+	    + sysctl_ktcpvs_keepalive_timeout * HZ;
+	tcp_vs_add_slowtimer(&sc->keepalive_timer);
 
 	/* put it back to the table */
 	tcp_vs_srvconn_hash(sc);
@@ -180,7 +187,7 @@ void tcp_vs_srvconn_put(server_conn_t *sc)
  *	Called just after a new connection entry is created.
  */
 static inline void
-tcp_vs_bind_dest(server_conn_t *sc, struct tcp_vs_dest *dest)
+tcp_vs_bind_dest(server_conn_t * sc, tcp_vs_dest_t * dest)
 {
 	/* if dest is NULL, then return directly */
 	if (!dest)
@@ -190,7 +197,8 @@ tcp_vs_bind_dest(server_conn_t *sc, struct tcp_vs_dest *dest)
 	atomic_inc(&dest->refcnt);
 	sc->dest = dest;
 
-	TCP_VS_DBG(4, "Bind a connection to the server TCP:%u.%u.%u.%u:%d\n",
+	TCP_VS_DBG(4,
+		   "Bind a connection to the server TCP:%u.%u.%u.%u:%d\n",
 		   NIPQUAD(sc->addr), ntohs(sc->port));
 }
 
@@ -199,14 +207,16 @@ tcp_vs_bind_dest(server_conn_t *sc, struct tcp_vs_dest *dest)
  *  Unbind a connection entry with its VS destination
  *  Called by the tcp_vs_srvconn_expire function.
  */
-static inline void tcp_vs_unbind_dest(server_conn_t *sc)
+static inline void
+tcp_vs_unbind_dest(server_conn_t * sc)
 {
-	struct tcp_vs_dest *dest = sc->dest;
+	tcp_vs_dest_t *dest = sc->dest;
 
 	if (!dest)
 		return;
 
-	TCP_VS_DBG(4, "Unbind a connection to the server TCP:%u.%u.%u.%u:%d\n",
+	TCP_VS_DBG(4,
+		   "Unbind a connection to the server TCP:%u.%u.%u.%u:%d\n",
 		   NIPQUAD(sc->addr), ntohs(sc->port));
 
 	sc->dest = NULL;
@@ -214,7 +224,8 @@ static inline void tcp_vs_unbind_dest(server_conn_t *sc)
 }
 
 
-void tcp_vs_srvconn_free(server_conn_t *sc)
+void
+tcp_vs_srvconn_free(server_conn_t * sc)
 {
 	/* close its socket */
 	if (sc->sock) {
@@ -230,7 +241,8 @@ void tcp_vs_srvconn_free(server_conn_t *sc)
 }
 
 
-static void tcp_vs_srvconn_expire(unsigned long data)
+static void
+tcp_vs_srvconn_expire(unsigned long data)
 {
 	server_conn_t *sc = (server_conn_t *) data;
 
@@ -238,14 +250,15 @@ static void tcp_vs_srvconn_expire(unsigned long data)
 		   "%u.%u.%u.%u:%d\n", NIPQUAD(sc->addr), ntohs(sc->port));
 
 	/*
-	 *	unhash it if it is hashed in the srvconn table
+	 *      unhash it if it is hashed in the srvconn table
 	 */
 	if (tcp_vs_srvconn_unhash(sc)) {
 		tcp_vs_srvconn_free(sc);
 		return;
 	}
 
-	TCP_VS_DBG(4, "The server connection (%u.%u.%u.%u:%d) expire later",
+	TCP_VS_DBG(4,
+		   "The server connection (%u.%u.%u.%u:%d) expire later",
 		   NIPQUAD(sc->addr), ntohs(sc->port));
 
 	tcp_vs_srvconn_put(sc);
@@ -256,14 +269,15 @@ static void tcp_vs_srvconn_expire(unsigned long data)
  *	Create a new connection entry to the specified server.
  */
 server_conn_t *
-tcp_vs_srvconn_new(struct tcp_vs_dest *dest)
+tcp_vs_srvconn_new(tcp_vs_dest_t * dest)
 {
 	server_conn_t *sc;
 	struct socket *sock;
 
 	sc = kmem_cache_alloc(srvconn_cachep, GFP_ATOMIC);
 	if (sc == NULL) {
-		TCP_VS_ERR_RL("tcp_vs_srvconn_new: no memory available.\n");
+		TCP_VS_ERR_RL
+		    ("tcp_vs_srvconn_new: no memory available.\n");
 		return NULL;
 	}
 
@@ -298,24 +312,25 @@ tcp_vs_srvconn_new(struct tcp_vs_dest *dest)
 /*
  *      Flush all the connection entries in the tcp_vs_srvconn_tab
  */
-static void tcp_vs_srvconn_flush(void)
+static void
+tcp_vs_srvconn_flush(void)
 {
 	int idx;
 	server_conn_t *sc;
 	struct list_head *l;
 
-  flush_again:
+      flush_again:
 	for (idx = 0; idx < SRVCONN_TAB_SIZE; idx++) {
 		/*
 		 *  Lock is actually needed in this loop.
 		 */
 		spin_lock(&srvconn_lock);
 
-		for (l = &srvconn_tab[idx]; !list_empty(l); ) {
+		for (l = &srvconn_tab[idx]; !list_empty(l);) {
 			sc = list_entry(l->next, server_conn_t, list);
 
 			__tcp_vs_srvconn_unhash(sc);
-			del_slowtimer(&sc->keepalive_timer);
+			tcp_vs_del_slowtimer(&sc->keepalive_timer);
 			tcp_vs_srvconn_free(sc);
 		}
 		spin_unlock(&srvconn_lock);
@@ -330,7 +345,8 @@ static void tcp_vs_srvconn_flush(void)
 }
 
 
-int tcp_vs_srvconn_init(void)
+int
+tcp_vs_srvconn_init(void)
 {
 	int idx;
 
@@ -350,7 +366,8 @@ int tcp_vs_srvconn_init(void)
 }
 
 
-void tcp_vs_srvconn_cleanup(void)
+void
+tcp_vs_srvconn_cleanup(void)
 {
 	/* flush all the connection entries first */
 	tcp_vs_srvconn_flush();
