@@ -1,7 +1,7 @@
 /*
  * tcpvs_config.c: parsing the tcpvs configuration file
  *
- * Version:	$Id: tcpvs_config.c,v 1.4 2003/05/23 02:08:34 wensong Exp $
+ * Version:	$Id: tcpvs_config.c,v 1.4.2.1 2004/10/30 16:28:14 wensong Exp $
  *
  * Authors:	Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -356,6 +356,13 @@ parse_rule(struct configfile *cf, void *param)
 	strncpy(rule->pattern, cf->token, KTCPVS_PATTERN_MAXLEN);
 
 	GET_TOKEN(cf);
+	if (!strcasecmp(cf->token, "match")) {
+		GET_TOKEN(cf);
+		rule->match_num = string_to_number(cf->token, 0, 10);
+		if (rule->match_num == -1) 
+			rule->match_num = 0;
+		GET_TOKEN(cf);
+	}
 	if (strcasecmp(cf->token, "use"))
 		return -1;
 
