@@ -1,7 +1,7 @@
 /*
  *      tcpvsadm - TCP Virtual Server ADMinistration program
  *
- *      Version: $Id: tcpvsadm.c,v 1.12.2.2 2004/10/31 04:06:19 wensong Exp $
+ *      Version: $Id: tcpvsadm.c,v 1.12.2.4 2004/12/08 14:06:31 wensong Exp $
  *
  *      Authors: Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -161,7 +161,6 @@ static struct option long_options[] = {
 	{"delete-service", 0, 0, 'D'},
 	{"flush", 0, 0, 'F'},
 	{"list", 0, 0, 'L'},
-	{"virtual-server", 0, 0, 'V'},
 	{"add-server", 0, 0, 'a'},
 	{"edit-server", 0, 0, 'e'},
 	{"delete-server", 0, 0, 'd'},
@@ -171,6 +170,7 @@ static struct option long_options[] = {
 	{"stop", 0, 0, '4'},
 	{"help", 0, 0, 'h'},
 	{"ident", 1, 0, 'i'},
+	{"listen", 0, 0, 'l'},
 	{"port", 1, 0, 'P'},
 	{"scheduler", 1, 0, 's'},
 	{"real-server", 1, 0, 'r'},
@@ -186,7 +186,7 @@ static struct option long_options[] = {
 int
 main(int argc, char **argv)
 {
-	const char *optstring = "AEDFaedLlf:hi:s:P:V:r:p:m:n";
+	const char *optstring = "AEDFaedLf:hi:s:l:P:r:p:m:n";
 	int c, parse;
 	char cf[128];
 	unsigned int command = CMD_NONE;
@@ -330,7 +330,7 @@ main(int argc, char **argv)
 		case 'm':
 			set_option(&options, OPT_MATCHNUM);
 			parse = string_to_number(optarg, 0, 10);
-			if (parse == -1) 
+			if (parse == -1)
 				fail(2, "illegal match number specified");
 			rule.match_num = parse;
 			break;
@@ -699,7 +699,7 @@ usage_exit(const int status)
 		"  --delete-server   -d        delete real server\n"
 		"  --add-rule                  add rule into virtual service\n"
 		"  --del-rule                  del rule into virtual service\n"
-		"  --list            -L|-l     list the table\n"
+		"  --list            -L        list the table\n"
 		"  --load-configfile -f        load a config file\n"
 		"  --start                     start the virtual services\n"
 		"  --stop                      stop the virtual services\n"
@@ -708,15 +708,15 @@ usage_exit(const int status)
 	fprintf(stream,
 		"Options:\n"
 		"  --ident        -i identity          service identity\n"
-		"  --scheduler    -s scheduler         one of wlc|http\n"
+		"  --scheduler    -s scheduler         one of %s\n"
 		"                                      the default scheduler is %s.\n"
 		"  --port         -p port              service port number\n"
 		"  --match        -m match-num         match number to hash (hhttp only)\n"
 		"  --real-server  -r server-address    server-address is host (and port)\n"
-		"  --virtual-server -V server-address    virtual server-address is host (and port)\n"
+		"  --listen       -l server-address    server-address is host (and port)\n"
 		"  --weight       -w weight            capacity of real server\n"
 		"  --numeric      -n                   numeric output of addresses and ports\n",
-		DEFAULT_SCHEDULER);
+		SCHEDULERS, DEFAULT_SCHEDULER);
 
 	exit(status);
 }
